#
# spec file for package python-taskw
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-taskw
Version:        2.0.0
Release:        2.3
Summary:        Python bindings for taskwarrior
License:        GPL-3.0-or-later
URL:            https://github.com/ralphbean/taskw
Source:         https://files.pythonhosted.org/packages/source/t/taskw/taskw-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#ralphbean/taskw#169
Patch0:         support-pytest-8.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-kitchen
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       taskwarrior
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module kitchen}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  taskwarrior
# /SECTION
%python_subpackages

%description
Python bindings for your taskwarrior database.

%prep
%autosetup -p1 -n taskw-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not test_filtering_brace'

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/taskw
%{python_sitelib}/taskw-%{version}.dist-info

%changelog
* Wed Aug 28 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-pytest-8.patch:
  * Support pytest 8.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Tue Sep 13 2022 pgajdos@suse.com
- version update to 2.0.0
  * This release is functionally identical to 1.3.1, but drops support for
    older versions of Python.  Before upgrading to this version of Taskw,
    make sure you're running Python 3.5 or newer.
  * does not require python-six
* Wed Feb 16 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.1:
  * Adds support for Taskwarrior 2.6.0
  * Fixes changelog syntax
  * Add tests for pull requests
- drop taskw-1.3.0-fix-build-with-taskwarrior-2.5.2.patch (upstream)
* Fri Aug 20 2021 Fusion Future <qydwhotmail@gmail.com>
- Add taskw-1.3.0-fix-build-with-taskwarrior-2.5.2.patch to fix
  build error with taskwarrior >= 2.5.2.
* Tue Dec  8 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.3.0
  * Pass taskrc via environment variable to subprocess.
  * Adds testing for Python 3.7 and 3.8
  * Fix error raised when taskwarrior is not installed.
  * Fix bug on deletion of completed task; disable confirmation for
    recurring tasks; fix bug in numeric deserialization.
  * Fixes bug in which UUIDs were improperly parsed
    when creating recurring tasks.
  * Fix a bug in which configuration values having an equal
    sign in their value would be improperly parsed.
  * Switched from nose to pytest.
  * Dropped automated testing for Python 3.4.
* Sat Oct 19 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Use single spec to add Python 3 support and tidy spec
- Update to v1.2.0
* Tue Jan  5 2016 sleep_walker@opensuse.org
- Initial spec for v1.1.0
